--[[
-------------------------------------------------------------------------------------
-------------------- PLUGIN GENERATEUR REMOTE KONTROL 3 AKWARIOM 2023 ---------------
-------------------------------------------------------------------------------------
VERSION OCTOBRE 2023 AVEC MENU.

- Permet de créer les remotes DMX ou MIDI nécessaires pour le fonctionnement
  du contrôleur KONTROL 3 AKWARIOM.
  Cette nouvelle version utilise un menu permettant de simplifier au maximum
  la création des remotes.
-------------------------------------------------------------------------------------

  PRECISION DE FONCTIONNEMENT
- Si des remotes DMX ou MIDI existent dans le REMOTE INPUT SETUPS, elles seront
  conservées et le plugin créera les remotes KONTROL 3 nécessaires à la suite.

- Pour la création de remotes DMX, le plugin assignera automatiquement dans le
  setup / MA Network Configuration, l'XLR In sur l'univers sélectionné et ce,
  aussi bien sur onpc que sur console.

- Possibilité de définir le numéro d'une page, permettant au KONTROL 3 AKWARIOM
  de contrôler l'ensemble des exécuteurs de cette page.
  Il est bien sur possible de définir l'option CurrentPage.

- Il est également possible de nommer la page associée. Le nom sera "KONTROL3 AKWARIOM"
  suivi du numéro de page. Néanmoins, cela reste facultatif afin d'éviter de renommer
  une page qui existerait et posséderait déjà un nom.

- Etant donné qu'il y a des personnes qui utilisent le contrôleur avec une GrandMa3 et
  que celle-ci ne possède pas de Grand Master (ce qui aurait alourdi considérablement
  son prix de vente), Il est donc possible d'assigner ou non le Grand Master sur le
  dernier fader du mode choisi. Exemple :
- Pour le mode Fader  1 à 15 : Le Grand Master sera assigné sur le fader 15 de la page associée.
- Pour le mode Fader 16 à 30 : Le Grand Master sera assigné sur le fader 30 de la page associée.
  et ainsi de suite.
  Dans le cas ou l'option de la page associée est 0 (CurrentPage) le Grand Master
  sera fixé à la page courante.
-------------------------------------------------------------------------------------

  UTILISATION DU PLUGIN :
- Lancer le plugin. Le menu s'affiche.
  Une aide succinte est disponible à la ligne n° 18 "-Aide-".
- Cliquer sur le menu "CREATION REMOTES DMX" ou "CREATION REMOTES MIDI".
  selon que vous voulez créer des remotes DMX ou MIDI. (vous pouvez bien sur
  créer les deux)
  Le menu aura dès lors le fond en VERT et les sous menus suivants seront
  maintenant accessibles.
  
- Cliquer sur un mode parmi les 6 disponibles. (ligne 5 à 10 du menu).
  Ils permettent la création des remotes selon la plage de fader désirée.
  Le mode choisi aura à présent le fond en VERT.
  
- Cliquer sur la ligne 12 du menu qui affichera selon la Création de remotes DMX
  ou MIDI, "UNIVERS IN ASSIGNÉ" ou "CANAL MIDI ASSIGNÉ".
  Un popup s'affichera permettant de saisir soit un numéro d'univers de 1 à 256,
  soit un canal midi de 1 à 16.
  L'univers DMX sera fictif, il permet de piloter les remotes.
  Aussi, choisir un univers assez lointain, par exemple 50.
  
- Cliquer sur la ligne 13 du menu "PAGE ASSIGNÉE". Cela affichera un popup
  permettant de saisir un numéro de page, page qui deviendra la page associée
  du contrôleur.
  Si vous ne souhaitez pas y associer de page ou si la page courante vous
  convient, saisir 0 (zéro) dans le popup et l'option "CurrentPage" sera
  sélectionnée.
  
- La ligne 14 du menu "NOM PAGE" fonctionne en mode toggle OUI / NON.
  En mode OUI, son inscription devient "NOM PAGE : OUI" et son fond est en VERT.
  En mode NON, son inscription devient "NOM PAGE : NON" et son fond est en VERT FONCÉ.
  Si OUI est choisi, le nom de la page associée sera "KONTROL 3 AKWARIOM".
  
- La ligne 15 du menu "GRANDMASTER ASSIGNÉ", fonctionne également en mode toggle OUI / NON.
  En mode OUI, son inscription devient "GRANDMASTER ASSIGNÉ : OUI" et son fond est en VERT.
  En mode NON, son inscription devient "GRANDMASTER ASSIGNÉ : NON" et son fond est en VERT FONCÉ.
  Si OUI est choisi, le GRANDMASTER sera assigné sur le dernier fader du mode choisi.
  Exemple :
- Pour le mode Fader  1 à 15 : Le Grand Master sera assigné sur le fader 15 de la page associée.
- Pour le mode Fader 16 à 30 : Le Grand Master sera assigné sur le fader 30 de la page associée.
  et ainsi de suite.
  Dans le cas ou l'option de la page associée est 0 ("Current Page") le Grand Master
  sera fixé sur le dernier fader de la page courante et donc disponible sur toutes les pages.
  
- Quand toutes les sélections ont étés faites, la ligne n° 17 "APPLIQUER" sera accessible
  et de couleur ROUGE VIF. Si ce n'est pas le cas, c'est qu'une option n'a pas été défini.
  
- Cliquer sur APPLIQUER et les remotes seront construites.
  Les remotes DMX ou MIDI du KONTROL 3 AKWARIOM sont opérationnelles.
-------------------------------------------------------------------------------------

  DESIGNATION DES MODES :
  MODE 1 : Création remotes Dmx/Midi pour les faders  1 à 15
  MODE 2 : Création remotes Dmx/Midi pour les faders 16 à 30
  MODE 3 : Création remotes Dmx/Midi pour les faders 31 à 45
  MODE 4 : Création remotes Dmx/Midi pour les faders 46 à 60
  MODE 5 : Création remotes Dmx/Midi pour les faders 61 à 75
  MODE 6 : Création remotes Dmx/Midi pour les faders 76 à 90

-------------------------------------------------------------------------------------
- Création REMOTE KONTROL2 AKWARIOM     - Janvier 2016 - v 3.1.2.5					-
- Amélioration REMOTE KONTROL2 AKWARIOM - Janvier 2018 - v 3.2.2.16					-
- Adaptation REMOTE KONTROL3 AKWARIOM   - Octobre 2022 - v 3.9.60.45				-
-------------------------------------------------------------------------------------
--]]
--------------------------------------------------
-- DEFINITION DES VARIABLES LOCALES
--------------------------------------------------
local sleep     = gma.sleep
local speed     = 0.02
local cmd       = gma.cmd
local fbk       = gma.feedback
local input     = gma.textinput
local Grab      = gma.show.getobj
local SgetVar   = gma.show.getvar;
local Confirmer = gma.gui.confirm;
local AlerteMsg = gma.gui.msgbox;

local InfoMode
local InfoAlerte
local IndicationNb
local IndicationNbExec

local LineCountFader
local CompteurFader
local CompteurExecFader
local LineCountBtn3
local CompteurBtn3
local CompteurExecBtn3
local LineCountBtn2
local CompteurBtn2
local CompteurExecBtn2
local LineCountBtn1
local CompteurBtn1
local CompteurExecBtn1
local LineCountEBtn
local CompteurEBtn
local CompteurExecEBtn
local PlacementGM			-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.

local MenuAkwariom01
local MenuAkwariom02
local MenuAkwariom03
local MenuAkwariom04
local MenuAkwariom05
local MenuAkwariom06
local MenuAkwariom07
local MenuAkwariom08
local MenuAkwariom09
local MenuAkwariom10
local MenuAkwariom11
local MenuAkwariom12
local MenuAkwariom13
local MenuAkwariom14
local MenuAkwariom15
local MenuAkwariom16
local MenuAkwariom17

DefinitionNomPage = DefinitionNomPage
DefinitionGm      = DefinitionGm

-- COLORISE LES INFOS DANS LA COMMAND LINE
-- Code couleur : 0m: NOIR / 1m:ROUGE / 2m:VERT / 3m:JAUNE / 4m:BLEU / 5m:CYAN / 6m:FUSHIA / 7m:BLANC
local ColorTxt = string.char(27)..'[3';

--------------------------------------------------
-- VARIABLES DES SCRIPTS
--------------------------------------------------
local LigneVierge, AnnulerPlugin, Aide;
local CreationRemoteDmx, CreationRemoteMidi;
local Mode1, Mode2, Mode3, Mode4, Mode5, Mode6;
local NumeroUnivers, NumeroCanalMidi, NumeroPage, NomPage, GrandMaster;
local Appliquer;

local LancementMenu, AkwariomKontrol3;
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- MENU PRINCIPAL
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
LancementMenu = function()
	
	--------------------------------------------------
	-- DEBUT DES OPERATION DU PLUGIN
	--------------------------------------------------
	fbk('');
	fbk(ColorTxt..'5m---------------------------------------------------------------------');
	fbk(ColorTxt..'5m              PLUGIN CREATION REMOTES KONTROL 3 AKWARIOM');
	fbk(ColorTxt..'5m---------------------------------------------------------------------');
	fbk('');
	
	----------------------------------------------------------------
	-- DEFINITION DES SCRIPTS POUR CHAQUE MENU
	----------------------------------------------------------------
	MenuAkwariom01 = "'Run_Kontrol(1)'"		-- CREATION REMOTES DMX
	MenuAkwariom02 = "'Run_Kontrol(2)'"		-- CREATION REMOTES MIDI
	MenuAkwariom03 = "'Run_Kontrol(3)'"		-- MODE 1 =  1 A 15
	MenuAkwariom04 = "'Run_Kontrol(4)'"		-- MODE 1 = 16 A 30
	MenuAkwariom05 = "'Run_Kontrol(5)'"		-- MODE 1 = 31 A 45
	MenuAkwariom06 = "'Run_Kontrol(6)'"		-- MODE 1 = 46 A 60
	MenuAkwariom07 = "'Run_Kontrol(7)'"		-- MODE 1 = 61 A 75
	MenuAkwariom08 = "'Run_Kontrol(8)'"		-- MODE 1 = 76 A 90
	MenuAkwariom09 = "'Run_Kontrol(9)'"		-- NUMERO UNIVERS
	MenuAkwariom10 = "'Run_Kontrol(10)'"	-- NUMERO PAGE ASSOCIÉE
	MenuAkwariom11 = "'Run_Kontrol(11)'"	-- NOM PAGE ASSOCIÉE
	MenuAkwariom12 = "'Run_Kontrol(12)'"	-- GRAND MASTER SUR DERNIER FADER
	MenuAkwariom13 = "'Run_Kontrol(13)'"	-- AIDE & INFOS
	MenuAkwariom14 = "'Run_Kontrol(14)'"	-- LIGNE VIERGE
	MenuAkwariom15 = "'Run_Kontrol(15)'"	-- QUITTER
	MenuAkwariom16 = "'Run_Kontrol(16)'"	-- APPLIQUER
	MenuAkwariom17 = "'Run_Kontrol(17)'"	-- NUMERO CANAL MIDI
	
	----------------------------------------------------------------
	-- CREATION DE L'EXECUTEUR DU MENU "CREATION PLAYLIST"
	----------------------------------------------------------------
	cmd('Store Seq "AKWARIOM" Cue 1 "- Kontrol 3 Akwariom -" /o /nc ; Store Seq "AKWARIOM" Cue 2 "CREATION REMOTES DMX" /o /nc ; Store Seq "AKWARIOM" Cue 3 "CREATION REMOTES MIDI" /o /nc ; Store Seq "AKWARIOM" Cue 4 "---" /o /nc ; Store Seq "AKWARIOM" Cue 5 "- FADER 1 à 15 " /o /nc ; Store Seq "AKWARIOM" Cue 6 "- FADER 16 à 30" /o /nc ; Store Seq "AKWARIOM" Cue 7 "- FADER 31 à 45" /o /nc ; Store Seq "AKWARIOM" Cue 8 "- FADER 46 à 60" /o /nc ; Store Seq "AKWARIOM" Cue 9 "- FADER 61 à 75" /o /nc ; Store Seq "AKWARIOM" Cue 10 "- FADER 76 à 90" /o /nc ; Store Seq "AKWARIOM" Cue 11 "---" /o /nc ; Store Seq "AKWARIOM" Cue 12 "---" /o /nc ; Store Seq "AKWARIOM" Cue 13 "Page Assignée" /o /nc ; Store Seq "AKWARIOM" Cue 14 "Nom Page" /o /nc ; Store Seq "AKWARIOM" Cue 15 "GrandMaster Assigné" /o /nc ; Store Seq "AKWARIOM" Cue 16 "---" /o /nc ; Store Seq "AKWARIOM" Cue 17 "APPLIQUER" /o /nc ; Store Seq "AKWARIOM" Cue 18 "- Aide -" /o /nc ; Store Seq "AKWARIOM" Cue 19 "QUITTER" /o /nc');
	fbk(ColorTxt..'7m-------');
	
	cmd('Appearance Seq "AKWARIOM" Cue 1 /r=26 /g=26 /b=26 ; Appearance Seq "AKWARIOM" Cue 2 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 3 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 4 /r=26 /g=26 /b=26 ; Appearance Seq "AKWARIOM" Cue 5 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 6 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 7 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 8 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 9 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 10 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 11 /r=26 /g=26 /b=26 ; Appearance Seq "AKWARIOM" Cue 12 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 13 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 14 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 15 /r=20 /g=20 /b=30 ; Appearance Seq "AKWARIOM" Cue 16 /r=26 /g=26 /b=26 ; Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25 ; Appearance Seq "AKWARIOM" Cue 18 /r=26 /g=26 /b=26 ; Appearance Seq "AKWARIOM" Cue 19 /r=0 /g=0 /b=0');
	fbk(ColorTxt..'7m-------');
	
	cmd('SetUserVar $MenuAkwariom01 = "'..MenuAkwariom01..'" ; SetUserVar $MenuAkwariom02 = "'..MenuAkwariom02..'" ; SetUserVar $MenuAkwariom03 = "'..MenuAkwariom03..'" ; SetUserVar $MenuAkwariom04 = "'..MenuAkwariom04..'" ; SetUserVar $MenuAkwariom05 = "'..MenuAkwariom05..'" ; SetUserVar $MenuAkwariom06 = "'..MenuAkwariom06..'" ; SetUserVar $MenuAkwariom07 = "'..MenuAkwariom07..'" ; SetUserVar $MenuAkwariom08 = "'..MenuAkwariom08..'" ; SetUserVar $MenuAkwariom09 = "'..MenuAkwariom09..'" ; SetUserVar $MenuAkwariom10 = "'..MenuAkwariom10..'" ; SetUserVar $MenuAkwariom11 = "'..MenuAkwariom11..'" ; SetUserVar $MenuAkwariom12 = "'..MenuAkwariom12..'" ; SetUserVar $MenuAkwariom13 = "'..MenuAkwariom13..'" ; SetUserVar $MenuAkwariom14 = "'..MenuAkwariom14..'" ; SetUserVar $MenuAkwariom15 = "'..MenuAkwariom15..'" ; SetUserVar $MenuAkwariom16 = "'..MenuAkwariom16..'" ; SetUserVar $MenuAkwariom17 = "'..MenuAkwariom17..'"');
	fbk(ColorTxt..'7m-------');
	
	cmd('Assign Seq "AKWARIOM" Cue 1 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 2 /cmd="LUA $MenuAkwariom01" ; Assign Seq "AKWARIOM" Cue 3 /cmd="LUA $MenuAkwariom02" ; Assign Seq "AKWARIOM" Cue 4 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 5 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 6 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 7 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 8 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 9 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 10 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 11 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 12 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 13 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 14 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 15 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 16 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14" ; Assign Seq "AKWARIOM" Cue 18 /cmd="LUA $MenuAkwariom13" ; Assign Seq "AKWARIOM" Cue 19 /cmd="LUA $MenuAkwariom15"');
	fbk(ColorTxt..'7m-------');
	
	cmd('Assign Seq "AKWARIOM" At Exec 1.200');
	cmd('Assign Goto ExecButton1 1.200');
	
	ChoixDmxMidi      = nil		-- Variable GLOBALE
	Mode	          = nil		-- Variable GLOBALE
	UniversSelect     = nil		-- Variable GLOBALE
	CanalMidi         = nil		-- Variable GLOBALE
	PageSelect        = nil		-- Variable GLOBALE
	ChoixNomPage      = nil		-- Variable GLOBALE
	ChoixGrandMaster  = nil		-- Variable GLOBALE
	
	cmd('Goto Exec 1.200');			-- Lancement du menu PRINCIPAL.
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- SELECTION DU SCRIPT SELON LE MENU CHOISI
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Run_Kontrol = function(ChoixMenu)
	
	if ChoixMenu     == 1 then
		
		CreationRemoteDmx()			-- CREATION REMOTES DMX
		
	elseif ChoixMenu == 2 then
		
		CreationRemoteMidi()		-- CREATION REMOTES MIDI
	
	elseif ChoixMenu == 3 then
		
		Mode1()						-- MODE 1 =  1 A 15
		
	elseif ChoixMenu == 4 then
		
		Mode2()						-- MODE 1 = 16 A 30
		
	elseif ChoixMenu == 5 then
		
		Mode3()						-- MODE 1 = 31 A 45
	
	elseif ChoixMenu == 6 then
		
		Mode4()						-- MODE 1 = 46 A 60
		
	elseif ChoixMenu == 7 then
	
		Mode5()						-- MODE 1 = 61 A 75
		
	elseif ChoixMenu == 8 then
		
		Mode6()						-- MODE 1 = 76 A 90
	
	elseif ChoixMenu == 9 then
		
		NumeroUnivers()				-- NUMERO UNIVERS
		
	elseif ChoixMenu == 10 then
		
		NumeroPage()				-- NUMERO PAGE ASSOCIÉE
		
	elseif ChoixMenu == 11 then
		
		NomPage()					-- NOM PAGE ASSOCIÉE
		
	elseif ChoixMenu == 12 then
		
		GrandMaster()				-- GRAND MASTER SUR DERNIER FADER
		
	elseif ChoixMenu == 13 then
		
		Aide()						-- AIDE & INFOS
		
	elseif ChoixMenu == 14 then
		
		LigneVierge()				-- LIGNE VIERGE
		
	elseif ChoixMenu == 15 then
		
		AnnulerPlugin()				-- QUITTER
		
	elseif ChoixMenu == 16 then
		
		Appliquer()					-- APPLIQUER
		
	elseif ChoixMenu == 17 then
		
		NumeroCanalMidi()			-- NUMERO CANAL MIDI
		
	end
end

--[[
***************************************************************************************************************************
****************************************************** SCRIPT DU MENU *****************************************************
***************************************************************************************************************************
--]]

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- QUITTER LE PLUGIN
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
AnnulerPlugin = function()
	
	-- Initialise les variables
	cmd('SetUserVar $MenuAkwariom01 = "" ; SetUserVar $MenuAkwariom02 = "" ; SetUserVar $MenuAkwariom03 = "" ; SetUserVar $MenuAkwariom04 = "" ; SetUserVar $MenuAkwariom05 = "" ; SetUserVar $MenuAkwariom06 = "" ; SetUserVar $MenuAkwariom07 = "" ; SetUserVar $MenuAkwariom08 = "" ; SetUserVar $MenuAkwariom09 = "" ; SetUserVar $MenuAkwariom10 = "" ; SetUserVar $MenuAkwariom11 = "" ; SetUserVar $MenuAkwariom12 = "" ; SetUserVar $MenuAkwariom13 = "" ; SetUserVar $MenuAkwariom14 = "" ; SetUserVar $MenuAkwariom15 = "" ; SetUserVar $MenuAkwariom16 = "" ; SetUserVar $MenuAkwariom17 = ""');
	
	cmd('Delete Seq "AKWARIOM" /nc');
	
	ChoixDmxMidi      = nil		-- Variable GLOBALE
	Mode	          = nil		-- Variable GLOBALE
	UniversSelect     = nil		-- Variable GLOBALE
	CanalMidi         = nil		-- Variable GLOBALE
	PageSelect        = nil		-- Variable GLOBALE
	ChoixNomPage      = nil		-- Variable GLOBALE
	ChoixGrandMaster  = nil		-- Variable GLOBALE
	DefinitionNomPage = "Non"
	DefinitionGm      = "Non"
	
	fbk('');
	fbk(ColorTxt..'5m---------------------------------------------------------------------');
	fbk(ColorTxt.."3mPLUGIN CREATION REMOTES KONTROL 3 AKWARIOM - Fin des opérations !");
	fbk(ColorTxt..'5m---------------------------------------------------------------------');
	fbk('');
end	
		
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- GESTION FONCTION AIDE ET INFOS
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Aide = function()
	
	if Confirmer('PLUGIN CREATION REMOTES KONTROL 3 AKWARIOM - MENU', "- Sélectionner \"CREATION REMOTES DMX\" ou \"CREATION REMOTES MIDI\".\n\n- Sélectionner un mode de contrôle des faders parmi les 6 disponibles.   \n- Définir un numéro d'Univers/Canal midi pour le pilotage des remotes.    \n- Définir un numéro de page qui sera associée (0 si CurrentPage).         \n- Définir un nom pour la page associée (OUI / NON).                            \n- Définir si le Grand Master doit être assigné sur le dernier exécuteur     \nfader du mode choisi (Si CurrentPage, il sera fixé) (OUI / NON).         \n\n- Ok pour continuer - Cancel pour quitter le plugin -\n") then
	
		cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
		
	else
		AnnulerPlugin()
	end
	
	fbk(ColorTxt..'7m-------');
end	

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- GESTION LIGNE VIERGE
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
LigneVierge = function()
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

--[[
***************************************************************************************************************************
***************************************************** SCRIPT DES ACTIONS ************************************************
***************************************************************************************************************************
--]]
	
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- CREATION REMOTES DMX
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
CreationRemoteDmx = function()
	
	ChoixDmxMidi      = 1
	Mode	          = nil		-- Variable GLOBALE
	UniversSelect     = nil		-- Variable GLOBALE
	CanalMidi         = nil		-- Variable GLOBALE
	PageSelect        = nil		-- Variable GLOBALE
	ChoixNomPage      = nil		-- Variable GLOBALE
	ChoixGrandMaster  = nil		-- Variable GLOBALE
	DefinitionNomPage = "Non"
	DefinitionGm      = "Non"
	
	cmd('Appearance Seq "AKWARIOM" Cue 2 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 2 /cmd="LUA $MenuAkwariom01"');
	cmd('Appearance Seq "AKWARIOM" Cue 3 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 3 /cmd="LUA $MenuAkwariom02"');
	
	cmd('Appearance Seq "AKWARIOM" Cue 5 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 5 /cmd="LUA $MenuAkwariom03"');
	cmd('Appearance Seq "AKWARIOM" Cue 6 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 6 /cmd="LUA $MenuAkwariom04"');
	cmd('Appearance Seq "AKWARIOM" Cue 7 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 7 /cmd="LUA $MenuAkwariom05"');
	cmd('Appearance Seq "AKWARIOM" Cue 8 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 8 /cmd="LUA $MenuAkwariom06"');
	cmd('Appearance Seq "AKWARIOM" Cue 9 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 9 /cmd="LUA $MenuAkwariom07"');
	cmd('Appearance Seq "AKWARIOM" Cue 10 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 10 /cmd="LUA $MenuAkwariom08"');
	
	cmd('Label Seq "AKWARIOM" Cue 12 "Univers IN Assigné"');
	cmd('Appearance Seq "AKWARIOM" Cue 12 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 12 /cmd="LUA $MenuAkwariom09"');
	cmd('Label Seq "AKWARIOM" Cue 13 "Page Assignée"');
	cmd('Appearance Seq "AKWARIOM" Cue 13 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 13 /cmd="LUA $MenuAkwariom10"');
	cmd('Label Seq "AKWARIOM" Cue 14 "Nom Page"');
	cmd('Appearance Seq "AKWARIOM" Cue 14 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 14 /cmd="LUA $MenuAkwariom11"');
	cmd('Label Seq "AKWARIOM" Cue 15 "GrandMaster Assigné"');
	cmd('Appearance Seq "AKWARIOM" Cue 15 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 15 /cmd="LUA $MenuAkwariom12"');
	
	cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
	cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- CREATION REMOTES MIDI
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
CreationRemoteMidi = function()
	
	ChoixDmxMidi      = 2
	Mode	          = nil		-- Variable GLOBALE
	UniversSelect     = nil		-- Variable GLOBALE
	CanalMidi         = nil		-- Variable GLOBALE
	PageSelect        = nil		-- Variable GLOBALE
	ChoixNomPage      = nil		-- Variable GLOBALE
	ChoixGrandMaster  = nil		-- Variable GLOBALE
	DefinitionNomPage = "Non"
	DefinitionGm      = "Non"
	
	cmd('Appearance Seq "AKWARIOM" Cue 2 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 2 /cmd="LUA $MenuAkwariom01"');
	cmd('Appearance Seq "AKWARIOM" Cue 3 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 3 /cmd="LUA $MenuAkwariom02"');
	
	cmd('Appearance Seq "AKWARIOM" Cue 5 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 5 /cmd="LUA $MenuAkwariom03"');
	cmd('Appearance Seq "AKWARIOM" Cue 6 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 6 /cmd="LUA $MenuAkwariom04"');
	cmd('Appearance Seq "AKWARIOM" Cue 7 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 7 /cmd="LUA $MenuAkwariom05"');
	cmd('Appearance Seq "AKWARIOM" Cue 8 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 8 /cmd="LUA $MenuAkwariom06"');
	cmd('Appearance Seq "AKWARIOM" Cue 9 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 9 /cmd="LUA $MenuAkwariom07"');
	cmd('Appearance Seq "AKWARIOM" Cue 10 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 10 /cmd="LUA $MenuAkwariom08"');
	
	cmd('Label Seq "AKWARIOM" Cue 12 "Canal Midi Assigné"');
	cmd('Appearance Seq "AKWARIOM" Cue 12 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 12 /cmd="LUA $MenuAkwariom17"');
	cmd('Label Seq "AKWARIOM" Cue 13 "Page Assignée"');
	cmd('Appearance Seq "AKWARIOM" Cue 13 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 13 /cmd="LUA $MenuAkwariom10"');
	cmd('Label Seq "AKWARIOM" Cue 14 "Nom Page"');
	cmd('Appearance Seq "AKWARIOM" Cue 14 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 14 /cmd="LUA $MenuAkwariom11"');
	cmd('Label Seq "AKWARIOM" Cue 15 "GrandMaster Assigné"');
	cmd('Appearance Seq "AKWARIOM" Cue 15 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 15 /cmd="LUA $MenuAkwariom12"');
	
	cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
	cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- GESTION DU MODE 1
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Mode1 = function()
	
	Mode = 1
	
	cmd('Appearance Seq "AKWARIOM" Cue 5 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 5 /cmd="LUA $MenuAkwariom03"');
	cmd('Appearance Seq "AKWARIOM" Cue 6 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 6 /cmd="LUA $MenuAkwariom04"');
	cmd('Appearance Seq "AKWARIOM" Cue 7 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 7 /cmd="LUA $MenuAkwariom05"');
	cmd('Appearance Seq "AKWARIOM" Cue 8 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 8 /cmd="LUA $MenuAkwariom06"');
	cmd('Appearance Seq "AKWARIOM" Cue 9 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 9 /cmd="LUA $MenuAkwariom07"');
	cmd('Appearance Seq "AKWARIOM" Cue 10 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 10 /cmd="LUA $MenuAkwariom08"');
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- GESTION DU MODE 2
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Mode2 = function()
	
	Mode = 2
	
	cmd('Appearance Seq "AKWARIOM" Cue 5 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 5 /cmd="LUA $MenuAkwariom03"');
	cmd('Appearance Seq "AKWARIOM" Cue 6 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 6 /cmd="LUA $MenuAkwariom04"');
	cmd('Appearance Seq "AKWARIOM" Cue 7 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 7 /cmd="LUA $MenuAkwariom05"');
	cmd('Appearance Seq "AKWARIOM" Cue 8 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 8 /cmd="LUA $MenuAkwariom06"');
	cmd('Appearance Seq "AKWARIOM" Cue 9 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 9 /cmd="LUA $MenuAkwariom07"');
	cmd('Appearance Seq "AKWARIOM" Cue 10 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 10 /cmd="LUA $MenuAkwariom08"');
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- GESTION DU MODE 3
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Mode3 = function()
	
	Mode = 3
	
	cmd('Appearance Seq "AKWARIOM" Cue 5 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 5 /cmd="LUA $MenuAkwariom03"');
	cmd('Appearance Seq "AKWARIOM" Cue 6 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 6 /cmd="LUA $MenuAkwariom04"');
	cmd('Appearance Seq "AKWARIOM" Cue 7 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 7 /cmd="LUA $MenuAkwariom05"');
	cmd('Appearance Seq "AKWARIOM" Cue 8 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 8 /cmd="LUA $MenuAkwariom06"');
	cmd('Appearance Seq "AKWARIOM" Cue 9 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 9 /cmd="LUA $MenuAkwariom07"');
	cmd('Appearance Seq "AKWARIOM" Cue 10 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 10 /cmd="LUA $MenuAkwariom08"');
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- GESTION DU MODE 4
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Mode4 = function()
	
	Mode = 4
	
	cmd('Appearance Seq "AKWARIOM" Cue 5 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 5 /cmd="LUA $MenuAkwariom03"');
	cmd('Appearance Seq "AKWARIOM" Cue 6 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 6 /cmd="LUA $MenuAkwariom04"');
	cmd('Appearance Seq "AKWARIOM" Cue 7 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 7 /cmd="LUA $MenuAkwariom05"');
	cmd('Appearance Seq "AKWARIOM" Cue 8 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 8 /cmd="LUA $MenuAkwariom06"');
	cmd('Appearance Seq "AKWARIOM" Cue 9 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 9 /cmd="LUA $MenuAkwariom07"');
	cmd('Appearance Seq "AKWARIOM" Cue 10 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 10 /cmd="LUA $MenuAkwariom08"');
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- GESTION DU MODE 5
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Mode5 = function()
	
	Mode = 5
	
	cmd('Appearance Seq "AKWARIOM" Cue 5 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 5 /cmd="LUA $MenuAkwariom03"');
	cmd('Appearance Seq "AKWARIOM" Cue 6 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 6 /cmd="LUA $MenuAkwariom04"');
	cmd('Appearance Seq "AKWARIOM" Cue 7 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 7 /cmd="LUA $MenuAkwariom05"');
	cmd('Appearance Seq "AKWARIOM" Cue 8 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 8 /cmd="LUA $MenuAkwariom06"');
	cmd('Appearance Seq "AKWARIOM" Cue 9 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 9 /cmd="LUA $MenuAkwariom07"');
	cmd('Appearance Seq "AKWARIOM" Cue 10 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 10 /cmd="LUA $MenuAkwariom08"');
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- GESTION DU MODE 6
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Mode6 = function()
	
	Mode = 6
	
	cmd('Appearance Seq "AKWARIOM" Cue 5 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 5 /cmd="LUA $MenuAkwariom03"');
	cmd('Appearance Seq "AKWARIOM" Cue 6 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 6 /cmd="LUA $MenuAkwariom04"');
	cmd('Appearance Seq "AKWARIOM" Cue 7 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 7 /cmd="LUA $MenuAkwariom05"');
	cmd('Appearance Seq "AKWARIOM" Cue 8 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 8 /cmd="LUA $MenuAkwariom06"');
	cmd('Appearance Seq "AKWARIOM" Cue 9 /r=20 /g=20 /b=30');
	cmd('Assign Seq "AKWARIOM" Cue 9 /cmd="LUA $MenuAkwariom07"');
	cmd('Appearance Seq "AKWARIOM" Cue 10 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 10 /cmd="LUA $MenuAkwariom08"');
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- NUMERO UNIVERS VIRTUEL
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
NumeroUnivers = function()
	
	::Univers::
	UniversSelect = input("Numéro d'univers (Dmx IN) ? \n(Univers 1 à 256)",'50');
	if tonumber(UniversSelect) == nil or tonumber(UniversSelect) == 0 or tonumber(UniversSelect) > 256 then goto Univers end
	
	cmd('Label Seq "AKWARIOM" Cue 12 "Univers IN Assigné : '..UniversSelect..'"');
	cmd('Appearance Seq "AKWARIOM" Cue 12 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 12 /cmd="LUA $MenuAkwariom09"');
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- NUMERO CANAL MIDI
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
NumeroCanalMidi = function()
	
	::CanalMidi::
	CanalMidi = input('Numéro Canal Midi ?\n(canal 1 à 16 )','1');
	if tonumber(CanalMidi) == nil or tonumber(CanalMidi) == 0 or tonumber(CanalMidi) > 16 then goto CanalMidi end

	cmd('Label Seq "AKWARIOM" Cue 12 "Canal Midi Assigné : '..CanalMidi..'"');
	cmd('Appearance Seq "AKWARIOM" Cue 12 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 12 /cmd="LUA $MenuAkwariom17"');
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- NUMERO PAGE ASSOCIÉE
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
NumeroPage = function()
	
	local DefinitionPage
	
	::Page::
	PageSelect = input('Numéro de Page ? 0= CurrentPage','5');
	if tonumber(PageSelect) == nil then goto Page end
	
	if tonumber(PageSelect) == 0 then
		DefinitionPage = "0 (CurrentPage)"
	elseif tonumber(PageSelect) ~= 0 then
		DefinitionPage = PageSelect
	end
	
	cmd('Label Seq "AKWARIOM" Cue 13 "Page Assignée : '..DefinitionPage..'"');
	cmd('Appearance Seq "AKWARIOM" Cue 13 /r=0 /g=50 /b=0');
	cmd('Assign Seq "AKWARIOM" Cue 13 /cmd="LUA $MenuAkwariom10"');
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- NOM PAGE ASSOCIÉE
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
NomPage = function()
		
	if DefinitionNomPage == "Non" or DefinitionNomPage == nil then
		DefinitionNomPage = "Oui"
		ChoixNomPage = 1
		cmd('Label Seq "AKWARIOM" Cue 14 "Nom Page : '..DefinitionNomPage..'"');
		cmd('Appearance Seq "AKWARIOM" Cue 14 /r=0 /g=50 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 14 /cmd="LUA $MenuAkwariom11"');
	
	elseif DefinitionNomPage == "Oui" then
		DefinitionNomPage = "Non"
		ChoixNomPage = 2
		cmd('Label Seq "AKWARIOM" Cue 14 "Nom Page : '..DefinitionNomPage..'"');
		cmd('Appearance Seq "AKWARIOM" Cue 14 /r=0 /g=20 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 14 /cmd="LUA $MenuAkwariom11"');
	end
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- GRAND MASTER SUR DERNIER FADER
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
GrandMaster = function()
	
	if DefinitionGm == "Non" or DefinitionGm == nil then
		DefinitionGm = "Oui"
		ChoixGrandMaster = 1
		cmd('Label Seq "AKWARIOM" Cue 15 "GrandMaster Assigné : '..DefinitionGm..'"');
		cmd('Appearance Seq "AKWARIOM" Cue 15 /r=0 /g=50 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 15 /cmd="LUA $MenuAkwariom12"');
		
	elseif DefinitionGm == "Oui" then
		DefinitionGm = "Non"
		ChoixGrandMaster = 2
		cmd('Label Seq "AKWARIOM" Cue 15 "GrandMaster Assigné : '..DefinitionGm..'"');
		cmd('Appearance Seq "AKWARIOM" Cue 15 /r=0 /g=20 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 15 /cmd="LUA $MenuAkwariom12"');
	end
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=80 /g=0 /b=0');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom16"');
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	end
	
	cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
	fbk(ColorTxt..'7m-------');
end

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- APPLIQUER
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Appliquer = function()
	
	if tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(UniversSelect) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		
		-- Initialise les variables
		cmd('SetUserVar $MenuAkwariom01 = "" ; SetUserVar $MenuAkwariom02 = "" ; SetUserVar $MenuAkwariom03 = "" ; SetUserVar $MenuAkwariom04 = "" ; SetUserVar $MenuAkwariom05 = "" ; SetUserVar $MenuAkwariom06 = "" ; SetUserVar $MenuAkwariom07 = "" ; SetUserVar $MenuAkwariom08 = "" ; SetUserVar $MenuAkwariom09 = "" ; SetUserVar $MenuAkwariom10 = "" ; SetUserVar $MenuAkwariom11 = "" ; SetUserVar $MenuAkwariom12 = "" ; SetUserVar $MenuAkwariom13 = "" ; SetUserVar $MenuAkwariom14 = "" ; SetUserVar $MenuAkwariom15 = "" ; SetUserVar $MenuAkwariom16 = "" ; SetUserVar $MenuAkwariom17 = ""');
		
		cmd('Delete Seq "AKWARIOM" /nc');
		
		AkwariomKontrol3()
		
	elseif tonumber(ChoixDmxMidi) ~= nil and tonumber(Mode) ~= nil and tonumber(CanalMidi) ~= nil and tonumber(PageSelect) ~= nil and ChoixNomPage ~= nil and tonumber(ChoixGrandMaster) ~= nil then
		
		-- Initialise les variables
		cmd('SetUserVar $MenuAkwariom01 = "" ; SetUserVar $MenuAkwariom02 = "" ; SetUserVar $MenuAkwariom03 = "" ; SetUserVar $MenuAkwariom04 = "" ; SetUserVar $MenuAkwariom05 = "" ; SetUserVar $MenuAkwariom06 = "" ; SetUserVar $MenuAkwariom07 = "" ; SetUserVar $MenuAkwariom08 = "" ; SetUserVar $MenuAkwariom09 = "" ; SetUserVar $MenuAkwariom10 = "" ; SetUserVar $MenuAkwariom11 = "" ; SetUserVar $MenuAkwariom12 = "" ; SetUserVar $MenuAkwariom13 = "" ; SetUserVar $MenuAkwariom14 = "" ; SetUserVar $MenuAkwariom15 = "" ; SetUserVar $MenuAkwariom16 = "" ; SetUserVar $MenuAkwariom17 = ""');
		
		cmd('Delete Seq "AKWARIOM" /nc');
		
		AkwariomKontrol3()
		
	else
		cmd('Appearance Seq "AKWARIOM" Cue 17 /r=50 /g=25 /b=25');
		cmd('Assign Seq "AKWARIOM" Cue 17 /cmd="LUA $MenuAkwariom14"');
	
		cmd('Goto Exec 1.200');			-- Réaffiche le menu "AKWARIOM"
		fbk(ColorTxt..'7m-------');
	end
end

--[[
***************************************************************************************************************************
****************************************************** SCRIPT REMOTES DMX *************************************************
***************************************************************************************************************************
--]]

-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- REMOTE KONTROL 3 AKWARIOM
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
AkwariomKontrol3 = function()
	
	-- SI UNE PAGE EST DÉFINIE AVEC UN NOM DE PAGE
	if tonumber(PageSelect) ~= 0 and tonumber(ChoixNomPage) == 1 then
		cmd('Store Page '..PageSelect);
		
		if ChoixDmxMidi == 1 then
			cmd('Label Page '..PageSelect..' "KONTROL3 AKWARIOM DMX '..PageSelect..'"');
		elseif ChoixDmxMidi == 2 then
			cmd('Label Page '..PageSelect..' "KONTROL3 AKWARIOM MIDI '..PageSelect..'"');
		end
		
	-- SI UNE PAGE EST DÉFINIE SANS NOM DE PAGE
	elseif tonumber(PageSelect) ~= 0 and tonumber(ChoixNomPage) == 2 then
		cmd('Store Page '..PageSelect);
		
	-- SI LA PAGE DÉFINIE EST "CURRENT PAGE"
	elseif tonumber(PageSelect) == 0 then
		PageSelect = "CurrentPage"
	end
	
	-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	-- CREATION REMOTES DMX
	-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	
	if tonumber(ChoixDmxMidi) == 1 then
		
		fbk('');	-- Espace vide
		fbk(ColorTxt..'5m----------------------------------------------------------------------------');
		fbk(ColorTxt.."5m                   PLUGIN REMOTES DMX AKWARIOM KONTROL 3");
		fbk(ColorTxt..'5m----------------------------------------------------------------------------');
		fbk('');	-- Espace vide
		
		--------------------------------------------------
		-- RECHERCHE SI DES REMOTES EXISTENT
		--------------------------------------------------
		local Cible         = '"REMOTETYPES"."DMXREMOTES"'
		local handle        = Grab.handle(Cible);
		local PremierRemote = Grab.amount(handle);
		local PremierRemote = tonumber(PremierRemote) +1
		local DernierRemote = tonumber(PremierRemote) +74
		
		--------------------------------------------------
		-- VARIABLES MODE 1 : KONTROL3 DMX 1 - 15
		--------------------------------------------------
		if tonumber(Mode)     == 1 then
		
			InfoMode          = "Mode 1 - Remotes Dmx 1 à 15"
			InfoAlerte        = "KONTROL3 DMX 1-15"
			IndicationNb      = "15"
			IndicationNbExec  = "115"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 1
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 1
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 1
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 1
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 101
			
			PlacementGM		  = 15		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.
			
		--------------------------------------------------
		-- VARIABLES MODE 2 : KONTROL3 DMX 16 - 30
		--------------------------------------------------
		elseif tonumber(Mode) == 2 then
		
			InfoMode          = "Mode 2 - Remotes Dmx 16 à 30"
			InfoAlerte        = "KONTROL3 DMX 16-30"
			IndicationNb      = "30"
			IndicationNbExec  = "130"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 16
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 16
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 16
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 16
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 116
			
			PlacementGM		  = 30		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.

		--------------------------------------------------
		-- VARIABLES MODE 3 : KONTROL3 DMX 31 - 45
		--------------------------------------------------
		elseif tonumber(Mode) == 3 then
		
			InfoMode          = "Mode 3 - Remotes Dmx 31 à 45"
			InfoAlerte        = "KONTROL3 DMX 31-45"
			IndicationNb      = "45"
			IndicationNbExec  = "145"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 31
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 31
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 31
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 31
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 131
			
			PlacementGM		  = 45		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.

		--------------------------------------------------
		-- VARIABLES MODE 4 : KONTROL3 DMX 46 - 60
		--------------------------------------------------
		elseif tonumber(Mode) == 4 then
		
			InfoMode          = "Mode 4 - Remotes Dmx 46 à 60"
			InfoAlerte        = "KONTROL3 DMX 46-60"
			IndicationNb      = "60"
			IndicationNbExec  = "160"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 46
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 46
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 46
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 46
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 146
			
			PlacementGM		  = 60		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.

		--------------------------------------------------
		-- VARIABLES MODE 5 : KONTROL3 DMX 61 - 75
		--------------------------------------------------
		elseif tonumber(Mode) == 5 then
		
			InfoMode          = "Mode 5 - Remotes Dmx 61 à 75"
			InfoAlerte        = "KONTROL3 DMX 61-75"
			IndicationNb      = "75"
			IndicationNbExec  = "175"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 61
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 61
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 61
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 61
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 161
			
			PlacementGM		  = 75		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.

		--------------------------------------------------
		-- VARIABLES MODE 6 : KONTROL3 DMX 76 - 90
		--------------------------------------------------
		elseif tonumber(Mode) == 6 then
		
			InfoMode          = "Mode 6 - Remotes Dmx 76 à 90"
			InfoAlerte        = "KONTROL3 DMX 76-90"
			IndicationNb      = "90"
			IndicationNbExec  = "190"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 76
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 76
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 76
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 76
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 176
			
			PlacementGM		  = 90		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.
		end
			
		-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
		--                              CONSTRUCTION REMOTES DMX
		-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	
		--------------------------------------------------
		-- CHANGE DESTINATION REMOTE DMX
		--------------------------------------------------
		cmd('Assign Remote "DmxRemotes" /enabled=1');
		sleep(speed);
		cmd('CD REMOTETYPES ; CD DMXREMOTES');
		sleep(speed);
		
		cmd('Store '..PremierRemote..' Thru '..DernierRemote);
		cmd('Label '..PremierRemote..' Thru '..DernierRemote..' "KONTROL3 1"');
		fbk(ColorTxt..'7m-------');
			
		--------------------------------------------------
		-- GESTION FADER
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountFader..' /Dmx='..UniversSelect..'.'..CompteurFader..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecFader..' /Button=fader /info="Fader : '..CompteurExecFader..' sur '..IndicationNb..'"');
			
			LineCountFader    = LineCountFader +1
			CompteurFader     = CompteurFader +1
			CompteurExecFader = CompteurExecFader +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
		
		--------------------------------------------------
		-- GESTION BOUTON 3 - HAUT
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountBtn3..' /Dmx='..UniversSelect..'.'..CompteurBtn3..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecBtn3..' /Button=2 /info="Bouton 3 : '..CompteurExecBtn3..' sur '..IndicationNb..'"');
			
			LineCountBtn3    = LineCountBtn3 +1
			CompteurBtn3     = CompteurBtn3 +1
			CompteurExecBtn3 = CompteurExecBtn3 +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
		
		--------------------------------------------------
		-- GESTION BOUTON 2 - MID
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountBtn2..' /Dmx='..UniversSelect..'.'..CompteurBtn2..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecBtn2..' /Button=1 /info="Bouton 2 : '..CompteurExecBtn2..' sur '..IndicationNb..'"');
			
			LineCountBtn2    = LineCountBtn2 +1
			CompteurBtn2     = CompteurBtn2 +1
			CompteurExecBtn2 = CompteurExecBtn2 +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
		
		--------------------------------------------------
		-- GESTION BOUTON 1 - BAS
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountBtn1..' /Dmx='..UniversSelect..'.'..CompteurBtn1..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecBtn1..' /Button=0 /info="Bouton 1 : '..CompteurExecBtn1..' sur '..IndicationNb..'"');
			
			LineCountBtn1    = LineCountBtn1 +1
			CompteurBtn1     = CompteurBtn1 +1
			CompteurExecBtn1 = CompteurExecBtn1 +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
		
		--------------------------------------------------
		-- GESTION EXECUTEUR BOUTON
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountEBtn..' /Dmx='..UniversSelect..'.'..CompteurEBtn..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecEBtn..' /Button=0 /info="Exec Btn : '..CompteurExecEBtn..' sur '..IndicationNbExec..'"');
			
			LineCountEBtn    = LineCountEBtn +1
			CompteurEBtn     = CompteurEBtn +1
			CompteurExecEBtn = CompteurExecEBtn +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
			
		--------------------------------------------------
		-- ASSIGNATION DU GRAND MASTER SELON CHOIX
		--------------------------------------------------
		if tonumber(ChoixGrandMaster) == 1 then
			
			if PageSelect == "CurrentPage" then
				cmd('Assign SpecialMaster 2.1 At Executor '..PlacementGM);
				cmd('Appearance Executor '..PlacementGM..' /r=100 /g=100 /b=0');
				cmd('Fix Executor '..PlacementGM);		-- Fixe l'exécuteur pour toutes les pages.
				
			else
				cmd('Assign SpecialMaster 2.1 At Executor '..PageSelect..'.'..PlacementGM);
				cmd('Appearance Executor '..PageSelect..'.'..PlacementGM..' /r=100 /g=100 /b=0');
			end
		end
		
		fbk(ColorTxt..'7m-------');
			
		--------------------------------------------------
		-- ASSIGNATION XLR IN UNIVERS
		--------------------------------------------------
		local ExploitationOs = SgetVar('OS');	 -- Recupère le système d'exploitation.
		
		if tostring(ExploitationOs) == "WINDOWS" then
			cmd('Assign Root NetConfig.onPC.*.1 /XLRC ="In '..UniversSelect..'"');
			AlerteMsg(InfoAlerte, 'Le remote \"KONTROL3 AKWARIOM DMX\" a été créé avec succès ! \n\n - ONPC utilisé.     - n° XlrIn Actif : '..UniversSelect..'\n\nLe contrôle du \"KONTROL3 AKWARIOM DMX\" est opérationnel !\n\nVous pouvez dès à présent assigner les exécuteurs    \nde la page n° '..PageSelect..'.                                                  ');
			
		elseif tostring(ExploitationOs) == "LINUX" then
			cmd('Assign Root NetConfig.Console.*.1 /XLRG ="In '..UniversSelect..'"');
			AlerteMsg(InfoAlerte, 'Le remote \"KONTROL3 AKWARIOM DMX\" a été créé avec succès ! \n\n - CONSOLE utilisé.     - n° XlrIn Actif : '..UniversSelect..'\n\nLe contrôle du \"KONTROL3 AKWARIOM DMX\" est opérationnel !\n\nVous pouvez dès à présent assigner les exécuteurs    \nde la page n° '..PageSelect..'.                                                  ');
		end
			
		--------------------------------------------------
		-- RECAPITULATIF INFOS COMMAND LINE
		--------------------------------------------------
		fbk('');
		fbk(ColorTxt..'5m------------------------------------------------------------------');
		fbk(ColorTxt..'5m  PLUGIN REMOTES DMX AKWARIOM KONTROL 3 - RECAPITULATIF');
		fbk(ColorTxt..'5m------------------------------------------------------------------');
		fbk(ColorTxt..'5mMode sélectionné                   : '..ColorTxt..'3m'..InfoMode);
		fbk(ColorTxt..'5mPage remote sélectionné            : '..ColorTxt..'3m'..PageSelect);
		fbk(ColorTxt..'5mUnivers sélectionné                : '..ColorTxt..'3m'..UniversSelect);
		fbk(ColorTxt..'5mNom première remote                : '..ColorTxt..'3m"KONTROL3 1"');
		fbk(ColorTxt..'5mAdresse dmx première remote        : '..ColorTxt..'3m'..UniversSelect..'.1');
		fbk(ColorTxt..'5mN° ligne première remote KONTROL 3 : '..ColorTxt..'3m'..PremierRemote);
		fbk(ColorTxt..'5mN° ligne dernière remote           : '..ColorTxt..'3m'..DernierRemote);
			
		if tostring(ExploitationOs) == "WINDOWS" then
			fbk(ColorTxt..'3mONPC'..ColorTxt..'5m - n° XlrIn actif              : '..ColorTxt..'3m'..UniversSelect);
			
		elseif tostring(ExploitationOs) == "LINUX" then
			fbk(ColorTxt..'3mCONSOLE'..ColorTxt..'5m - n° XlrIn actif           : '..ColorTxt..'3m'..UniversSelect);
		end
		
		fbk('');
		fbk(ColorTxt..'5m------------------------------------------------------------------');
		fbk(ColorTxt..'5mVous pouvez dès à présent assigner les exécuteurs de la page n° '..ColorTxt..'3m'..PageSelect);
		fbk(ColorTxt.."5mpour qu'ils puissent être contrôlés avec votre appareil.");
		fbk(ColorTxt..'5m------------------------------------------------------------------');
		fbk('');
		
		cmd('CD /');
		
		ChoixDmxMidi     = nil		-- Variable GLOBALE
		Mode	         = nil		-- Variable GLOBALE
		UniversSelect    = nil		-- Variable GLOBALE
		CanalMidi        = nil		-- Variable GLOBALE
		PageSelect       = nil		-- Variable GLOBALE
		ChoixNomPage     = nil		-- Variable GLOBALE
		ChoixGrandMaster = nil		-- Variable GLOBALE
		
	-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	-- CREATION REMOTES MIDI
	-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	
	elseif tonumber(ChoixDmxMidi) == 2 then
		
		fbk('');	-- Espace vide
		fbk(ColorTxt..'5m----------------------------------------------------------------------------');
		fbk(ColorTxt.."5m                   PLUGIN REMOTES MIDI AKWARIOM KONTROL 3");
		fbk(ColorTxt..'5m----------------------------------------------------------------------------');
		fbk('');	-- Espace vide
		
		--------------------------------------------------
		-- RECHERCHE SI DES REMOTES EXISTENT
		--------------------------------------------------
		local Cible         = '"REMOTETYPES"."MIDIREMOTES"'
		local handle        = Grab.handle(Cible);
		local PremierRemote = Grab.amount(handle);
		local PremierRemote = tonumber(PremierRemote) +1
		local DernierRemote = tonumber(PremierRemote) +74
		
		--------------------------------------------------
		-- VARIABLES MODE 1 : KONTROL3 MIDI 1 - 15
		--------------------------------------------------
		if tonumber(Mode)     == 1 then
		
			InfoMode          = "Mode 1 - Remotes Midi 1 à 15"
			InfoAlerte        = "KONTROL3 MIDI 1-15"
			IndicationNb      = "15"
			IndicationNbExec  = "115"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 1
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 1
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 1
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 1
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 101
			
			PlacementGM		  = 15		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.
		
		--------------------------------------------------
		-- VARIABLES MODE 2 : KONTROL3 MIDI 16 - 30
		--------------------------------------------------
		elseif tonumber(Mode) == 2 then
		
			InfoMode          = "Mode 2 - Remotes Midi 16 à 30"
			InfoAlerte        = "KONTROL3 MIDI 16-30"
			IndicationNb      = "30"
			IndicationNbExec  = "130"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 16
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 16
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 16
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 16
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 116
			
			PlacementGM		  = 30		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.

		--------------------------------------------------
		-- VARIABLES MODE 3 : KONTROL3 MIDI 31 - 45
		--------------------------------------------------
		elseif tonumber(Mode) == 3 then
		
			InfoMode          = "Mode 3 - Remotes Midi 31 à 45"
			InfoAlerte        = "KONTROL3 MIDI 31-45"
			IndicationNb      = "45"
			IndicationNbExec  = "145"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 31
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 31
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 31
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 31
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 131
			
			PlacementGM		  = 45		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.

		--------------------------------------------------
		-- VARIABLES MODE 4 : KONTROL3 MIDI 46 - 60
		--------------------------------------------------
		elseif tonumber(Mode) == 4 then
		
			InfoMode          = "Mode 4 - Remotes Midi 46 à 60"
			InfoAlerte        = "KONTROL3 MIDI 46-60"
			IndicationNb      = "60"
			IndicationNbExec  = "160"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 46
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 46
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 46
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 46
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 146
			
			PlacementGM		  = 60		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.

		--------------------------------------------------
		-- VARIABLES MODE 5 : KONTROL3 MIDI 61 - 75
		--------------------------------------------------
		elseif tonumber(Mode) == 5 then
		
			InfoMode          = "Mode 5 - Remotes Midi 61 à 75"
			InfoAlerte        = "KONTROL3 MIDI 61-75"
			IndicationNb      = "75"
			IndicationNbExec  = "175"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 61
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 61
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 61
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 61
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 161
			
			PlacementGM		  = 75		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.

		--------------------------------------------------
		-- VARIABLES MODE 6 : KONTROL3 MIDI 76 - 90
		--------------------------------------------------
		elseif tonumber(Mode) == 6 then
		
			InfoMode          = "Mode 6 - Remotes Midi 76 à 90"
			InfoAlerte        = "KONTROL3 MIDI 76-90"
			IndicationNb      = "90"
			IndicationNbExec  = "190"
			
			LineCountFader    = PremierRemote
			CompteurFader     = 1
			CompteurExecFader = 76
			
			LineCountBtn3     = PremierRemote +15
			CompteurBtn3      = 16
			CompteurExecBtn3  = 76
			
			LineCountBtn2     = PremierRemote +30
			CompteurBtn2      = 31
			CompteurExecBtn2  = 76
			
			LineCountBtn1     = PremierRemote +45
			CompteurBtn1      = 46
			CompteurExecBtn1  = 76
			
			LineCountEBtn     = PremierRemote +60
			CompteurEBtn      = 61
			CompteurExecEBtn  = 176
			
			PlacementGM		  = 90		-- Emplacement du Grand Master sur dernier fader selon le mode sélectionnée.
		end
			
		-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
		--                              CONSTRUCTION REMOTES MIDI
		-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
		
		--------------------------------------------------
		-- CHANGE DESTINATION REMOTE MIDI
		--------------------------------------------------
		cmd('Assign Remote "MidiRemotes" /enabled=1');
		sleep(speed);
		cmd('CD REMOTETYPES ; CD MIDIREMOTES');
		sleep(speed);
		
		cmd('Store '..PremierRemote..' Thru '..DernierRemote);
		cmd('Label '..PremierRemote..' Thru '..DernierRemote..' "KONTROL3 1"');
		fbk(ColorTxt..'7m-------');
		
		--------------------------------------------------
		-- GESTION FADER
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountFader..' /Note='..CompteurFader..' /channel='..CanalMidi..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecFader..' /Button=fader /info="Fader : '..CompteurExecFader..' sur '..IndicationNb..'"');
			LineCountFader    = LineCountFader +1
			CompteurFader     = CompteurFader +1
			CompteurExecFader = CompteurExecFader +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
		
		--------------------------------------------------
		-- GESTION BOUTON 3 - HAUT
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountBtn3..' /Note='..CompteurBtn3..' /channel='..CanalMidi..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecBtn3..' /Button=2 /info="Bouton 3 : '..CompteurExecBtn3..' sur '..IndicationNb..'"');
			LineCountBtn3    = LineCountBtn3 +1
			CompteurBtn3     = CompteurBtn3 +1
			CompteurExecBtn3 = CompteurExecBtn3 +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
		
		--------------------------------------------------
		-- GESTION BOUTON 2 - MID
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountBtn2..' /Note='..CompteurBtn2..' /channel='..CanalMidi..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecBtn2..' /Button=1 /info="Bouton 2 : '..CompteurExecBtn2..' sur '..IndicationNb..'"');
			LineCountBtn2    = LineCountBtn2 +1
			CompteurBtn2     = CompteurBtn2 +1
			CompteurExecBtn2 = CompteurExecBtn2 +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
		
		--------------------------------------------------
		-- GESTION BOUTON 1 - BAS
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountBtn1..' /Note='..CompteurBtn1..' /channel='..CanalMidi..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecBtn1..' /Button=0 /info="Bouton 1 : '..CompteurExecBtn1..' sur '..IndicationNb..'"');
			LineCountBtn1    = LineCountBtn1 +1
			CompteurBtn1     = CompteurBtn1 +1
			CompteurExecBtn1 = CompteurExecBtn1 +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
		
		--------------------------------------------------
		-- GESTION EXECUTEUR BOUTON
		--------------------------------------------------
		for i = 1 , 15 , 1 do
			cmd('Assign '..LineCountEBtn..' /Note='..CompteurEBtn..' /channel='..CanalMidi..' /Type=Exec /Page='..PageSelect..' /Executor='..CompteurExecEBtn..' /Button=0 /info="Exec Btn : '..CompteurExecEBtn..' sur '..IndicationNb..'"');
			LineCountEBtn    = LineCountEBtn +1
			CompteurEBtn     = CompteurEBtn +1
			CompteurExecEBtn = CompteurExecEBtn +1
			sleep(speed);
			fbk(ColorTxt..'7m-------');
		end
			
		--------------------------------------------------
		-- ASSIGNATION DU GRAND MASTER SELON CHOIX
		--------------------------------------------------
		if tonumber(ChoixGrandMaster) == 1 then
			
			if PageSelect == "CurrentPage" then
				cmd('Assign SpecialMaster 2.1 At Executor '..PlacementGM);
				cmd('Appearance Executor '..PlacementGM..' /r=100 /g=100 /b=0');
				cmd('Fix Executor '..PlacementGM);		-- Fixe l'exécuteur pour toutes les pages.
				
			else
				cmd('Assign SpecialMaster 2.1 At Executor '..PageSelect..'.'..PlacementGM);
				cmd('Appearance Executor '..PageSelect..'.'..PlacementGM..' /r=100 /g=100 /b=0');
			end
		end
		
		fbk(ColorTxt..'7m-------');
			
		--------------------------------------------------
		-- RECAPITULATIF INFOS COMMAND LINE
		--------------------------------------------------
		fbk('');
		fbk(ColorTxt..'5m------------------------------------------------------------------');
		fbk(ColorTxt..'5m  PLUGIN REMOTES MIDI AKWARIOM KONTROL 3 - RECAPITULATIF');
		fbk(ColorTxt..'5m------------------------------------------------------------------');
		fbk(ColorTxt..'5mMode sélectionné                   : '..ColorTxt..'3m'..InfoMode);
		fbk(ColorTxt..'5mPage remote sélectionné            : '..ColorTxt..'3m'..PageSelect);
		fbk(ColorTxt..'5mNom première remote                : '..ColorTxt..'3m"KONTROL3 1"');
		fbk(ColorTxt..'5mNuméro Canal midi                  : '..ColorTxt..'3m'..CanalMidi);
		fbk(ColorTxt..'5mN° ligne première remote KONTROL 3 : '..ColorTxt..'3m'..PremierRemote);
		fbk(ColorTxt..'5mN° ligne dernière remote           : '..ColorTxt..'3m'..DernierRemote);
			
		--------------------------------------------------
		-- DETERMINE LE SYSTEME D'EXPLOITATION
		--------------------------------------------------
		local ExploitationOs = SgetVar('OS');	 -- Recupère le système d'exploitation.
		
		if tostring(ExploitationOs) == "WINDOWS" then
			AlerteMsg(InfoAlerte, 'Le remote \"KONTROL3 AKWARIOM MIDI\" a été créé avec succès ! \n\n - ONPC utilisé.     - Système exploitation WINDOWS\n\nLe contrôle du \"KONTROL3 AKWARIOM MIDI\" est opérationnel !\n\nVous pouvez dès à présent assigner les exécuteurs    \nde la page n° '..PageSelect..'.                                                  ');
			
		elseif tostring(ExploitationOs) == "LINUX" then
			AlerteMsg(InfoAlerte, 'Le remote \"KONTROL3 AKWARIOM MIDI\" a été créé avec succès ! \n\n - 3mCONSOLE utilisé.     - Système exploitation LINUX\n\nLe contrôle du \"KONTROL3 AKWARIOM MIDI\" est opérationnel !\n\nVous pouvez dès à présent assigner les exécuteurs    \nde la page n° '..PageSelect..'.                                                  ');
		end

		fbk('');
		fbk(ColorTxt..'5m------------------------------------------------------------------');
		fbk(ColorTxt..'5mVous pouvez dès à présent assigner les exécuteurs de la page n° '..ColorTxt..'3m'..PageSelect..',');
		fbk(ColorTxt.."5mpour qu'ils puissent être contrôlés avec votre appareil.");
		fbk(ColorTxt..'5m------------------------------------------------------------------');
		fbk('');
		
		cmd('CD /');
		
		ChoixDmxMidi     = nil		-- Variable GLOBALE
		Mode	         = nil		-- Variable GLOBALE
		UniversSelect    = nil		-- Variable GLOBALE
		CanalMidi        = nil		-- Variable GLOBALE
		PageSelect       = nil		-- Variable GLOBALE
		ChoixNomPage     = nil		-- Variable GLOBALE
		ChoixGrandMaster = nil		-- Variable GLOBALE
	
	end
end

return LancementMenu;
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX